Developers
Projects
GET /projects
Returns all projects of current account.
{
"projects": [
{
"project": {
...
}
},
...
]
}
<projects>
<project>
...
</project>
...
</projects>
GET /companies/company_id/projects
Returns all projects of a specific company.
{
"projects": [
{
"project": {
...
}
},
...
]
}
<projects>
<project>
...
</project>
...
</projects>
GET /companies/company_id/projects/project_id
Returns a single project identified by its ID.
{
"project": {
...
}
}
<project>
...
</project>
POST /companies/company_id/projects
Create a new project
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&project[name]=project_name' https://www.triggerapp.com/api/v1/companies/company_id/projects
Parameters:
| Attribute | Required? | Type | Remarks | name | yes | string | name of the project |
|---|---|---|---|
| description | no | string | |
| status | no | string | can either be opportunity, open (default), on_hold or closed |
| due_date | no | date | multiple formats allowed but use YYYY/MM/DD for clarity |
| billable | no | boolean | can either be blank (default - company based), true or false |
| billable_type | no | string | can either be Hourly or Fixed |
| fixed_rate | no | decimal | |
| task_rate | no | decimal | |
| estimated_time | no | decimal | |
| accessible_to_clients | no | boolean | defaults to true |
Response:
Returns status code 200 on success and the json or xml of the current project.
Failed requests will return 400.
PUT /companies/company_id/projects/project_id
Update an existing project
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&project[name]=project_name&project[description]=project_description&...' -X https://www.triggerapp.com/api/v1/companies/company_id/projects/project_id
Response:
Returns status code 200 on success and the json or xml of the current project.
Failed requests will return 400.
DELETE /companies/company_id/projects/project_id
Destroy an existing project
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX' -X DELETE https://www.triggerapp.com/api/v1/companies/company_id/projects/project_id
Response:
Returns status code 204 on success and no content.
Failed requests will return 400.
Trigger is closing on 30 April 2027 and is no longer accepting new accounts. Existing customers can still sign in.